<!--
Copyright (C) 2020 CESNET z.s.p.o.

oarepo-documents is free software; you can redistribute it and/or modify it
under the terms of the MIT License; see LICENSE file for more details.
-->

# Changes 

## Version 1.0.0 

- Initial public release.
